import glob
import numpy as np
import cv2
import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd
import os
import re
from scipy import signal
from sklearn.linear_model import LinearRegression


if __name__ == "__main__":
    cmap = sns.color_palette()
    cmap_hm = "plasma"

    dirs = glob.glob("./_HS*")
    strains = sorted([k[3:] for k in dirs])  # strainを重複なく抜き出す
    for cmp in strains_to_omit:
        if cmp in strains:
            strains.remove(cmp)     # plotに使いたくないやつを除く

    data_CFP = pd.DataFrame({})
    data_FRET = pd.DataFrame({})
    data_length = pd.DataFrame({})
    for cmp in strains:
        temp_CFP = pd.read_csv("./_" + cmp + "\_results_tot_CFP.csv")
        temp_FRET = pd.read_csv("./_" + cmp + "\_results_tot_FRET.csv")
        temp_length = pd.read_csv("./_" + cmp + "\_results_tot_length.csv")

        data_CFP = pd.concat([data_CFP, temp_CFP], ignore_index=True)
        data_FRET = pd.concat([data_FRET, temp_FRET], ignore_index=True)
        data_length = pd.concat([data_length, temp_length], ignore_index=True)
        print(cmp, len(data_length))


    data_plt = pd.DataFrame({})
    data_plt["ratio"] = data_FRET["Mean"]/data_CFP["Mean"]
    data_plt["length"] = data_length["Length"]
    data_plt["strain"] = data_FRET["strain"]

    data_plt.drop(data_plt.loc[data_plt["length"] > 50].index, inplace=True)

    fig = plt.figure(figsize=(8, 6))
    sns.scatterplot(x="length", y="ratio", data=data_plt, hue="strain", alpha=0.3, legend=True)

    df_length = pd.read_csv("./length-at-division.csv")
    strains = sorted(df_length["strain"].unique().tolist())  # strainを重複なく抜き出す
    df_mean = df_length.groupby("strain", as_index=False).mean()
    df_sd = df_length.groupby("strain", as_index=False).std()
    print(df_sd)
    for i in range(len(strains)):
        length = [k for k in df_mean.loc[df_mean["strain"] == strains[i]]["length"]][0]
        sd = [k for k in df_sd.loc[df_sd["strain"] == strains[i]]["length"]][0]
        plt.axvspan(xmin=length-sd, xmax=length+sd, color=cmap[i], alpha=0.1)
    """
    for cmp in dirs:
        model_lr = LinearRegression()
        x = [[k] for k in data_plt.loc[data_plt["strain"] == cmp[3:]]["length"]]
        y = data_plt.loc[data_plt["strain"] == cmp[3:]]["ratio"]
        model_lr.fit(x, y)
        plt.plot(x, model_lr.predict(x), linestyle="solid")
        print(model_lr.score(x, y))
    """
    plt.savefig("./__length-vs-FRET.pdf")
    plt.close(fig)
